package jdk.internal.util.xml.impl;

import java.io.OutputStreamWriter;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import jdk.internal.util.xml.XMLStreamException;
import java.nio.charset.Charset;
import java.io.OutputStream;
import java.nio.charset.CharsetEncoder;
import java.io.Writer;

public class XMLWriter
{
    private Writer _writer;
    private CharsetEncoder _encoder;
    
    public XMLWriter(OutputStream outputStream, String s, Charset charset) throws XMLStreamException {
        this._encoder = null;
        this._encoder = charset.newEncoder();
        try {
            this._writer = this.getWriter(outputStream, s, charset);
        }
        catch (UnsupportedEncodingException th) {
            throw new XMLStreamException(th);
        }
    }
    
    public boolean canEncode(char c) {
        return this._encoder != null && this._encoder.canEncode(c);
    }
    
    public void write(String s) throws XMLStreamException {
        try {
            this._writer.write(s.toCharArray());
        }
        catch (IOException th) {
            throw new XMLStreamException("I/O error", th);
        }
    }
    
    public void write(String str, int off, int len) throws XMLStreamException {
        try {
            this._writer.write(str, off, len);
        }
        catch (IOException th) {
            throw new XMLStreamException("I/O error", th);
        }
    }
    
    public void write(char[] array, int n, int n2) throws XMLStreamException {
        try {
            this._writer.write(array, n, n2);
        }
        catch (IOException th) {
            throw new XMLStreamException("I/O error", th);
        }
    }
    
    void write(int c) throws XMLStreamException {
        try {
            this._writer.write(c);
        }
        catch (IOException th) {
            throw new XMLStreamException("I/O error", th);
        }
    }
    
    void flush() throws XMLStreamException {
        try {
            this._writer.flush();
        }
        catch (IOException th) {
            throw new XMLStreamException(th);
        }
    }
    
    void close() throws XMLStreamException {
        try {
            this._writer.close();
        }
        catch (IOException th) {
            throw new XMLStreamException(th);
        }
    }
    
    private void nl() throws XMLStreamException {
        String property = System.getProperty("line.separator");
        try {
            this._writer.write(property);
        }
        catch (IOException th) {
            throw new XMLStreamException("I/O error", th);
        }
    }
    
    private Writer getWriter(OutputStream outputStream, String charsetName, Charset cs) throws XMLStreamException, UnsupportedEncodingException {
        if (cs != null) {
            return new OutputStreamWriter(new BufferedOutputStream(outputStream), cs);
        }
        return new OutputStreamWriter(new BufferedOutputStream(outputStream), charsetName);
    }
}
